Usage
lagrangian.pdd(grid, x, y, proj='', npart.released=length(x), res=c(1e3,
1e3), log=F,
xlim=c(min(x), max(x)), ylim=c(min(y), max(y)), zlim=NA)Arguments
grid
An unstructured grid that could be passed to
plot.att
x
A vector of particle x locations.
y
A vector of particle y locations.
proj
A string to project the (x,y) coordinates to
latitude-longitude using the PROJ.4 library. If proj is an empty
string, the points are not projected, and units='m' is passed to
att.plot.
npart.released
The number of particles released.
res
The size of the grid cells to bin particles into in
meters.
log
Should the data be plotted on a log scale
xlim
x limits for plotting and binning the data.
ylim
y limits for plotting and binning the data.
zlim
z limits to be passed through to image.